
.main-body {
 display: flex;
 gap: 20px;
}

.body-detail{
  width: 70%;
}



.monitor-status {
  width: 25%;
}

.job-table-list {
  width: 100%;
  margin-top: 2rem;
}
.checker-row {
  padding-top: 1.5rem;
  padding-bottom: 1.5rem;
}

.checker-row .check-active {
  color: green;
  margin-right: 1rem;
}

.checker-row .updated-time {
  color: grey;
  margin-right: 0.3rem;
}

.pa-information {
  color: gray;
}
