import{I as n}from"./index-6QKa2Ynx.js";import{I as e}from"./index-s_3b95Qx.js";import{p as r,I as s}from"./index-Bfvs1Dps.js";function I(o,t){var a=r(o);return t===s.STANDARD?n[a]:e[a]}function p(o){return r(o)}export{n as IconSvgPaths16,e as IconSvgPaths20,I as getIconPaths,p as iconNameToPathsRecordKey};
