import{_ as o,a as _,b as i,p as c,I as u}from"./index-Bfvs1Dps.js";var p=function(n,s){return o(void 0,void 0,void 0,function(){var a,r;return _(this,function(e){switch(e.label){case 0:return a=c(n),s!==u.STANDARD?[3,2]:[4,i(()=>import("./index-6QKa2Ynx.js").then(t=>t.I),__vite__mapDeps([]))];case 1:return r=e.sent(),[3,4];case 2:return[4,i(()=>import("./index-s_3b95Qx.js").then(t=>t.I),__vite__mapDeps([]))];case 3:r=e.sent(),e.label=4;case 4:return[2,r[a]]}})})};export{p as splitPathsBySizeLoader};
function __vite__mapDeps(indexes) {
  if (!__vite__mapDeps.viteFileDeps) {
    __vite__mapDeps.viteFileDeps = []
  }
  return indexes.map((i) => __vite__mapDeps.viteFileDeps[i])
}
