import{_ as o,a as n,b as i}from"./index-Bfvs1Dps.js";var _=function(e,a){return o(void 0,void 0,void 0,function(){var t;return n(this,function(r){switch(r.label){case 0:return[4,i(()=>import("./allPaths-cuJB7CbI.js"),__vite__mapDeps([0,1,2,3,4]))];case 1:return t=r.sent().getIconPaths,[2,t(e,a)]}})})};export{_ as allPathsLoader};
function __vite__mapDeps(indexes) {
  if (!__vite__mapDeps.viteFileDeps) {
    __vite__mapDeps.viteFileDeps = ["assets/allPaths-cuJB7CbI.js","assets/index-6QKa2Ynx.js","assets/index-s_3b95Qx.js","assets/index-Bfvs1Dps.js","assets/index-Zttfj1Qn.css"]
  }
  return indexes.map((i) => __vite__mapDeps.viteFileDeps[i])
}
