@import "normalize.css";
@import "@blueprintjs/core/lib/css/blueprint.css";
@import "@blueprintjs/icons/lib/css/blueprint-icons.css";

.app-body {
  padding: 3rem;
}


.margin-right {
  margin-right: .5rem;
}
